function [choix, ColNo, paraName, nPara] = choixparametres( fid, DELIMITER );
%
% $Id$
%
% 
% Cette fonction permet a l'utilisateur de choisir les parametres presents
% dans le fichier et qui seront utilises par le programme.
% Le choix se fait sur les parametres suivants :
%              date, heure, lat, lon
% La fonction retournera systematiquement les parametres suivants
%                cond, hcond, sog, cog
%
% [ColNo, nPara] = choixparametres( fid, DELIMITER );
%
% Input
%   fid ........... Numero logique du fichier a decoder
%   DELIMITER ..... caractere separant chaque parametre a decoder sur
%                   une ligne
%
% output
%   choix ......... String 'yes' ou 'cancel' qui indique si le programme
%                   doit s'arretter
%   ColNo ......... Structure donnant pour chaque parametre le numero de
%                   la colonne a lire
%   paraName ...... Intitule des parametres de la ligne d'entete 
%   nPara ......... Nombre de parametre total present dans le fichier
%
% ------------------------------------------------------------------------
    
% Initialisation de la structure indiquant le numero de colonnes des parametres
% presents dans le fichier intial et qui seront utilises dans TSG-QC
% --------------------------------------------------------------
ColNo = struct( 'Date', 0, 'Time', 0, 'Lat', 0, 'Lon', 0, 'Temp', 0,...
                'Sal', 0, 'Cond', 0, 'Raw', 0, 'Sog', 0, 'Cog', 0);

% Initialisation des indices de colonne de la conductivite et des valeurs
% brutes que l'on conserve systematiquement
% -----------------------------------------------------------------------
condNo = 0;
rawNo = 0;

% Lecture de la 1ere ligne
%
% ATTENTION : Je considere que cette ligne est la ligne d'entete
% FAIRE UN TEST POUR VERIFIER QUE C'EST BIEN  UNE LIGNE D'ENTETE
% --------------------------------------------------------------
firstLine = fgets( fid );
    
% Decode la ligne d'entete et place l'intitule de chaque colonne
% dans une variable de type 'cell' : paraName avec nPara elements
% -------------------------------------------------------------------
[paraName, nPara] = decodestr( firstLine, DELIMITER );

% Convertit les intitules de chaque colonne en caracteres minuscules
% ------------------------------------------------------------------
paraName = lower(paraName);

% Tant que 'choix' est egal  'yes' on propose a l'utilisateur
% de faire le choix des entetes. Si le choix est fait, 'choix' est 
% positionne a 'ok'
% ------------------------------------------------------------
choix = 'yes';
while strcmp( choix, 'yes' )
  
  % Affiche les entetes et demande un choix a l'utilisateur
  % La fonction renvoie le numero des colonnes qui ont ete choisies
  %
  % ---------------------------------------------------------------
  ind = 0;
  for ipar = 1 : nPara
    header = char( paraName(1, ipar) );
    
    if strfind( header, 'pc date') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'pc time') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'sbe21_temp1') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'sbe21_sal') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'sbe21_cond') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
      condNo = ipar;
    elseif strfind( header, 'sbe21_raw') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
      rawNo = ipar;
    elseif strfind( header, 'latdec') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'londec') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'sog') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    elseif strfind( header, 'cog') ~= 0
      ind = ind + 1;
      defAnsB(ind) = ipar;
    end
    
  end     % fin de boucle for ipar =
  
  % Affichage d'une 'boite a liste' pour le choix des parametres
  % ------------------------------------------------------------
  [colParaNo, okCol] = listdlg('PromptString', 'Choix des paramtres',...
                       'ListString', paraName, 'InitialValue', defAnsB);
  
  % Le programme conserve systematiquement la conductivite et les valeurs
  % brutes
  % ---------------------------------------------------------------------
  if rawNo ~= 0
    i = find( colParaNo == rawNo );
    if isempty(i)
      colParaNo = [colParaNo rawNo];
    end
  end
  if condNo ~= 0
    i = find( colParaNo == condNo );
    if isempty(i)
      colParaNo = [colParaNo condNo];
    end
  end

  if okCol == 1
    
    % Le choix s'est bien passe
    % -------------------------
    choix = 'ok';
    
    % Boucle sur les numeros de colonnes des parametres qui seront conserves
    % ----------------------------------------------------------------------
    if ~isempty(okCol)
      for icol = 1 : length(colParaNo)
  
        % Convertion en caracteres
        % ------------------------
        header = char( paraName(1, colParaNo(icol)) );

        % Place les numeros des colonnes dans la structure
        % ------------------------------------------------
        if strfind( header, 'date') ~= 0
          ColNo.Date = colParaNo(icol);
        elseif strfind( header, 'time') ~= 0
          ColNo.Time = colParaNo(icol);
        elseif strfind( header, 'lat') ~= 0
          ColNo.Lat = colParaNo(icol);
        elseif strfind( header, 'lon') ~= 0
          ColNo.Lon = colParaNo(icol);
        elseif strfind( header, 'temp') ~= 0
          ColNo.Temp = colParaNo(icol);
        elseif strfind( header, 'sal') ~= 0
          ColNo.Sal = colParaNo(icol);
        elseif strfind( header, 'cond') ~= 0
          ColNo.Cond = colParaNo(icol);
        elseif strfind( header, 'raw') ~= 0
          ColNo.Raw = colParaNo(icol);
        elseif strfind( header, 'sog') ~= 0
          ColNo.Sog = colParaNo(icol);
        elseif strfind( header, 'cog') ~= 0
          ColNo.Cog = colParaNo(icol);
        end
      end
    end

    % Gestion d'erreur
    % ----------------
    if ColNo.Date == 0
      choix = questdlg('Date - Voulez-vous refaire votre choix ?',...
        'Aucune date choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Time == 0
      choix = questdlg('Heure - Voulez-vous refaire votre choix ?',...
        'Aucune heure choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Lat == 0
      choix = questdlg('Latitude - Voulez-vous refaire votre choix ?',...
        'Aucune latitude choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Lon == 0
      choix = questdlg('Longitude - Voulez-vous refaire votre choix ?',...
        'Aucune longitude choisie', 'yes', 'cancel', 'yes');
    end
    
  else
    
    % On annulle le choix des parametres. Le programme se termine
    % -----------------------------------------------------------
    choix = 'cancel';
    
  end     % fin de test if okCol == 1
  
end       % Fin de boucle While

% Revient en debut de fichier
% ---------------------------
frewind(fid);
