function [nblig, DataIn] = rdtsglabview( fileName )
% 
% $Id$
%
% Fonction de lecture des fichiers TSG issus du programme
% d'acquisition LabView XXX
%
% [nblig, ttt] = rdtsglabview( Fichier )
%
% Input
%   fileName ..... Nom du fichier a lire (chemin + nom fichier)
%
% Output
%   nblig ........ Nombre de lignes du tableau 'ttt'
%   DataIn ....... Tableau de structure
%
%     DataIn(nblig).An, DataIn(nblig).Mois, DataIn(nblig).Jour
%     DataIn(nblig).Heure, DataIn(nblig).Min, DataIn(nblig).Sec,
%     DataIn(nblig).Lat, DataIn(nblig).Lon
%     DataIn(nblig).Sst, DataIn(nblig).Sss, DataIn(nblig).Cond
%     DataIn(nblig).Sog, DataIn(nblig).Cog
%     DataIn(nblig).Raw, DataIn(nblig).ndate
%
%     Ce sont des numrique a l'execption de 'Raw' qui sont des cellules de
%     caracteres.
%
% Liste des intitules des colonnes dans les entetes des fichiers Labview :
% Date
%     Pc Date  - RMC_Date - ZDA_Date
% Heure
%     Pc Time - RMC_Time - ZDA_Time - GLL_Time
% Position
%     RMC_Latmn - RMC_Lonmn - RMC_Latdec - RMC_Londec - GGA_Latdec - GGA_Londec
%     GLL_Latdec - GLL_Londec
% Mesures
%     SBE21_Temp1 - SBE21_Sal - SBE21_Cond - SBE21_Raw
% Vitesse et cap
%     RMC_Sog - RMC_Cog - 3026L_Cog - 3026L_Sog
% Autre
%     RMC_Status - GGA_Hog - VTG True Track - T - Magn Track - M - Ground spd
%     N - Ground Spd - K - dd - tete - ttt
% -----------------------------------------------------------------------------

disp(' -- DECODAGE LABVIEW  --')


% Chaque colonne du fichier est separee par DELIMITER
% ---------------------------------------------------
DELIMITER = ',';
  
% Parametres en sortie vides
% --------------------------
nblig = 0;
DataIn = [];
  
% Ouverture du fichier '.CSV'
% ---------------------------
fid = fopen( fileName, 'r');

% Teste si le fichier existe
% --------------------------
if fid ~= -1
    
  % Choix des parametres qui seront utilises par TSG-QC
  % ColNo : structure des numeros de colonnes a conserver
  % ---------------------------------------------------
  [choix, ColNo, paraName, nPara] = choixparametres( fid, DELIMITER );
  
  if strcmp( choix, 'ok' ) == 1
    
    % Lecture et decodage du fichier TSG LabView
    % ------------------------------------------
    [date, time, lat, lon, sst, sss, cond, condRaw, sog, cog] =...
                    decodeficlabview( fid, DELIMITER, ColNo, paraName, nPara ); 
  
    % Indice des lignes pour lesquelles les dates
    % ou les heures ne sont pas a NaN
    % -------------------------------------------
    noNaN = find( strcmp( date, 'NaN') == 0 & strcmp( time, 'NaN') == 0 );

    % Nombre de lignes du fichier et allocation de memoire
    % ----------------------------------------------------
    nblig = length(sst);
    an = NaN * ones( nblig, 1 );
    mois = an; jour = an; heure = an; min = an; sec = an; dateNo = an;
  
    % Decoupage de la Date : an, mois, jour, etc.
    % Calcul de la date : numerique Matlab
    % -------------------------------------------
    blanc = char(blanks(1)*ones(nblig,1));
  
    [an(noNaN),mois(noNaN),jour(noNaN),heure(noNaN),min(noNaN),sec(noNaN)]...
              = datevec( [char(date(noNaN)) blanc(noNaN) char(time(noNaN))],...
                          'dd/mm/yyyy HH:MM:SS');
    dateNo(noNaN) = datenum(...
    [char(date(noNaN)) blanc(noNaN) char(time(noNaN))], 'dd/mm/yyyy HH:MM:SS');
    
    % Cree la structure definitive
    % ----------------------------
    DataIn = struct('An', num2cell(an), 'Mois', num2cell(mois),...
      'Jour', num2cell(jour),'Heure', num2cell(heure), 'Min', num2cell(min),...
      'Sec', num2cell(sec), 'Lat', num2cell(lat), 'Lon', num2cell(lon),...
      'Sst', num2cell(sst), 'Sss', num2cell(sss), 'Cond', num2cell(cond),...
      'Sog', num2cell(sog), 'Cog', num2cell(cog), 'Raw', cellstr(condRaw),...
      'ndate', num2cell(dateNo) );
    
  end  % fin de boucle if strcmp(choix,'yes')
    
  % Fermeture du fichier
  % --------------------
  fclose( fid );

else

  % Gestion d'erreur ouverture de fichier
  % -------------------------------------
  msgbox(['Le fichier ' FicEntree( ific, :) ' n''existe pas'], 'Fichier')
    
end
